==> ark-23.04.0.tar.xz: ark-23.04.0/plugins/libarchive/kerfuffle_libarchive.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for compressed TAR archives",
        "Description[ar]": "دعم كامل لأرشيفات TAR المضغوطة",
        "Description[ast]": "Compatibilidá completa colos archivos TAR comprimíos",
        "Description[az]": "Sıxılmış TAR arxivlərinin tam dəstəklənməsi",
        "Description[be]": "Поўная падтрымка фармату TAR",
        "Description[bg]": "Пълна поддръжка на компресирани архиви TAR",
        "Description[ca@valencia]": "Implementació completa dels arxius TAR comprimits",
        "Description[ca]": "Implementació completa dels arxius TAR comprimits",
        "Description[cs]": "Plná podpora komprimovaných archivů TAR",
        "Description[da]": "Fuld understøttelse af TAR-arkiver",
        "Description[de]": "Vollständige Unterstützung für komprimierte TAR-Archive",
        "Description[el]": "Πλήρης υποστήριξη για αρχειοθήκες TAR",
        "Description[en_GB]": "Full support for compressed TAR archives",
        "Description[eo]": "Plena subteno por kunpremitaj TAR-arkivoj",
        "Description[es]": "Uso total de los archivos comprimidos TAR",
        "Description[et]": "Pakitud TAR-arhiivide täielik toetus",
        "Description[eu]": "Konprimatutako TAR artxiboentzako euskarri osoa",
        "Description[fi]": "Pakattujen Tar-arkistojen täysi tuki",
        "Description[fr]": "Prise en charge complète des archives compressées TAR",
        "Description[gl]": "Compatibilidade total con arquivos TAR comprimidos.",
        "Description[hu]": "Teljes támogatás tömörített TAR archívumokhoz",
        "Description[ia]": "Suppoto complete per archivos comprimite TAR",
        "Description[id]": "Dukungan penuh untuk arsip TAR terkompresi",
        "Description[ie]": "Complet supporte por compresset archives TAR",
        "Description[is]": "Fullur stuðningur við þjappaðar TAR safnskrár",
        "Description[it]": "Supporto completo per archivi compressi TAR",
        "Description[ja]": "圧縮された TAR アーカイブに完全に対応",
        "Description[ka]": "შეკუმშული TAR არქივების სრული მხარდაჭერა",
        "Description[ko]": "압축된 TAR 형식 전체 지원",
        "Description[nl]": "Volledige ondersteuning voor gecomprimeerde TAR-archieven",
        "Description[nn]": "Full støtte for komprimerte TAR-arkiv",
        "Description[pl]": "Pełna obsługa dla archiwów TAR",
        "Description[pt]": "Suporte total para pacotes comprimidos do TAR",
        "Description[pt_BR]": "Suporte total a arquivos compactados TAR",
        "Description[ro]": "Suport complet pentru arhive TAR comprimate",
        "Description[ru]": "Полная поддержка сжатых архивов TAR",
        "Description[sk]": "Plná podpora komprimovaných archívov TAR",
        "Description[sl]": "Polna podpora za arhive vrste TAR",
        "Description[sr@ijekavian]": "Пуна подршка за компресоване тар архиве",
        "Description[sr@ijekavianlatin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr@latin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr]": "Пуна подршка за компресоване тар архиве",
        "Description[sv]": "Fullt stöd för komprimerade TAR-arkiv",
        "Description[tr]": "Sıkıştırılmış TAR arşivleri için tam destek",
        "Description[uk]": "Повноцінна підтримка стиснених архівів TAR",
        "Description[x-test]": "xxFull support for compressed TAR archivesxx",
        "Description[zh_CN]": "完整支持 TAR 压缩包文件",
        "Description[zh_TW]": "對壓縮過的 TAR 壓縮檔的完整支援",
        "Id": "kerfuffle_libarchive",
        "MimeTypes": [
            "application/x-tar",
            "application/x-compressed-tar",
            "application/x-bzip-compressed-tar",
            "application/x-tarz",
            "application/x-xz-compressed-tar",
            "application/x-lzma-compressed-tar",
            "application/x-lzip-compressed-tar",
            "application/x-tzo",
            "application/x-lrzip-compressed-tar",
            "application/x-lz4-compressed-tar",
            "application/x-zstd-compressed-tar"
        ],
        "Name": "Libarchive plugin",
        "Name[ar]": "ملحق Libarchive",
        "Name[ast]": "Plugin de libarchive",
        "Name[az]": "Libarchive qoşması",
        "Name[be]": "Убудова Libarchive",
        "Name[bg]": "Приставка Libarchive",
        "Name[ca@valencia]": "Connector de Libarchive",
        "Name[ca]": "Connector del Libarchive",
        "Name[cs]": "Modul libarchive",
        "Name[da]": "Libarchive-plugin",
        "Name[de]": "LibArchive-Modul",
        "Name[el]": "Πρόσθετο Libarchive",
        "Name[en_GB]": "Libarchive plugin",
        "Name[eo]": "Libarchive-kromaĵo",
        "Name[es]": "Complemento Libarchive",
        "Name[et]": "Libarchive'i plugin",
        "Name[eu]": "Libarchive plugina",
        "Name[fi]": "Libarchive-liitännäinen",
        "Name[fr]": "Module externe « libarchive »",
        "Name[gl]": "Complemento de libarchive",
        "Name[hu]": "Libarchive bővítmény",
        "Name[ia]": "Libarchive plugin",
        "Name[id]": "Plugin Libarchive",
        "Name[ie]": "Plugin de Libarchive",
        "Name[is]": "Libarchive-viðbót",
        "Name[it]": "Estensione Libarchive",
        "Name[ja]": "Libarchive プラグイン",
        "Name[ka]": "Libarchive -ის მხარდაჭერა",
        "Name[ko]": "Libarchive 플러그인",
        "Name[nl]": "LibArchive-plug-in",
        "Name[nn]": "Libarchive-tillegg",
        "Name[pl]": "Wtyczka libarchive",
        "Name[pt]": "'Plugin' da Libarchive",
        "Name[pt_BR]": "Plugin Libarchive",
        "Name[ro]": "Extensie Libarchive",
        "Name[ru]": "Модуль Libarchive",
        "Name[sk]": "Plugin Libarchive",
        "Name[sl]": "Vstavek Libarchive",
        "Name[sr@ijekavian]": "Прикључак за Либархив",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive",
        "Name[sr@latin]": "Priključak za libarchive",
        "Name[sr]": "Прикључак за Либархив",
        "Name[sv]": "Libarchive-insticksprogram",
        "Name[tr]": "Libarchive eklentisi",
        "Name[uk]": "Додаток libarchive",
        "Name[x-test]": "xxLibarchive pluginxx",
        "Name[zh_CN]": "Libarchive 插件",
        "Name[zh_TW]": "Libarchive 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 100,
    "application/x-bzip-compressed-tar": {
        "CompressionLevelDefault": 9,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lrzip-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lz4-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lzip-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-lzma-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-tzo": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-xz-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-zstd-compressed-tar": {
        "CompressionLevelDefault": 3,
        "CompressionLevelMax": 22,
        "CompressionLevelMin": 1
    }
}

==> ark-23.08.1.tar.xz: ark-23.08.1/plugins/libarchive/kerfuffle_libarchive.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for compressed TAR archives",
        "Description[ar]": "دعم كامل لأرشيفات TAR المضغوطة",
        "Description[ast]": "Compatibilidá completa colos archivos TAR comprimíos",
        "Description[az]": "Sıxılmış TAR arxivlərinin tam dəstəklənməsi",
        "Description[be]": "Поўная падтрымка фармату TAR",
        "Description[bg]": "Пълна поддръжка на компресирани архиви TAR",
        "Description[ca@valencia]": "Implementació completa dels arxius TAR comprimits",
        "Description[ca]": "Implementació completa dels arxius TAR comprimits",
        "Description[cs]": "Plná podpora komprimovaných archivů TAR",
        "Description[da]": "Fuld understøttelse af TAR-arkiver",
        "Description[de]": "Vollständige Unterstützung für komprimierte TAR-Archive",
        "Description[el]": "Πλήρης υποστήριξη για αρχειοθήκες TAR",
        "Description[en_GB]": "Full support for compressed TAR archives",
        "Description[eo]": "Plena subteno por kunpremitaj TAR-arkivoj",
        "Description[es]": "Uso total de los archivos comprimidos TAR",
        "Description[et]": "Pakitud TAR-arhiivide täielik toetus",
        "Description[eu]": "Konprimatutako TAR artxiboentzako euskarri osoa",
        "Description[fi]": "Pakattujen Tar-arkistojen täysi tuki",
        "Description[fr]": "Prise en charge complète des archives compressées TAR",
        "Description[gl]": "Compatibilidade total con arquivos TAR comprimidos.",
        "Description[hu]": "Teljes támogatás tömörített TAR archívumokhoz",
        "Description[ia]": "Suppoto complete per archivos comprimite TAR",
        "Description[id]": "Dukungan penuh untuk arsip TAR terkompresi",
        "Description[ie]": "Complet supporte por compresset archives TAR",
        "Description[is]": "Fullur stuðningur við þjappaðar TAR safnskrár",
        "Description[it]": "Supporto completo per archivi compressi TAR",
        "Description[ja]": "圧縮された TAR アーカイブに完全に対応",
        "Description[ka]": "შეკუმშული TAR არქივების სრული მხარდაჭერა",
        "Description[ko]": "압축된 TAR 형식 전체 지원",
        "Description[nl]": "Volledige ondersteuning voor gecomprimeerde TAR-archieven",
        "Description[nn]": "Full støtte for komprimerte TAR-arkiv",
        "Description[pl]": "Pełna obsługa dla archiwów TAR",
        "Description[pt]": "Suporte total para pacotes comprimidos do TAR",
        "Description[pt_BR]": "Suporte total a arquivos compactados TAR",
        "Description[ro]": "Suport complet pentru arhive TAR comprimate",
        "Description[ru]": "Полная поддержка сжатых архивов TAR",
        "Description[sk]": "Plná podpora komprimovaných archívov TAR",
        "Description[sl]": "Polna podpora za arhive vrste TAR",
        "Description[sr@ijekavian]": "Пуна подршка за компресоване тар архиве",
        "Description[sr@ijekavianlatin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr@latin]": "Puna podrška za kompresovane tar arhive",
        "Description[sr]": "Пуна подршка за компресоване тар архиве",
        "Description[sv]": "Fullt stöd för komprimerade TAR-arkiv",
        "Description[tr]": "Sıkıştırılmış TAR arşivleri için tam destek",
        "Description[uk]": "Повноцінна підтримка стиснених архівів TAR",
        "Description[x-test]": "xxFull support for compressed TAR archivesxx",
        "Description[zh_CN]": "完整支持 TAR 压缩文件",
        "Description[zh_TW]": "對壓縮過的 TAR 壓縮檔的完整支援",
        "Id": "kerfuffle_libarchive",
        "MimeTypes": [
            "application/x-tar",
            "application/x-compressed-tar",
            "application/x-bzip-compressed-tar",
            "application/x-tarz",
            "application/x-xz-compressed-tar",
            "application/x-lzma-compressed-tar",
            "application/x-lzip-compressed-tar",
            "application/x-tzo",
            "application/x-lrzip-compressed-tar",
            "application/x-lz4-compressed-tar",
            "application/x-zstd-compressed-tar"
        ],
        "Name": "Libarchive plugin",
        "Name[ar]": "ملحق Libarchive",
        "Name[ast]": "Plugin de libarchive",
        "Name[az]": "Libarchive qoşması",
        "Name[be]": "Убудова Libarchive",
        "Name[bg]": "Приставка Libarchive",
        "Name[ca@valencia]": "Connector de Libarchive",
        "Name[ca]": "Connector del Libarchive",
        "Name[cs]": "Modul libarchive",
        "Name[da]": "Libarchive-plugin",
        "Name[de]": "LibArchive-Modul",
        "Name[el]": "Πρόσθετο Libarchive",
        "Name[en_GB]": "Libarchive plugin",
        "Name[eo]": "Libarchive-kromaĵo",
        "Name[es]": "Complemento Libarchive",
        "Name[et]": "Libarchive'i plugin",
        "Name[eu]": "Libarchive plugina",
        "Name[fi]": "Libarchive-liitännäinen",
        "Name[fr]": "Module externe « libarchive »",
        "Name[gl]": "Complemento de libarchive",
        "Name[hu]": "Libarchive bővítmény",
        "Name[ia]": "Libarchive plugin",
        "Name[id]": "Plugin Libarchive",
        "Name[ie]": "Plugin de Libarchive",
        "Name[is]": "Libarchive-viðbót",
        "Name[it]": "Estensione Libarchive",
        "Name[ja]": "Libarchive プラグイン",
        "Name[ka]": "Libarchive -ის მხარდაჭერა",
        "Name[ko]": "Libarchive 플러그인",
        "Name[nl]": "LibArchive-plug-in",
        "Name[nn]": "Libarchive-tillegg",
        "Name[pl]": "Wtyczka libarchive",
        "Name[pt]": "'Plugin' da Libarchive",
        "Name[pt_BR]": "Plugin Libarchive",
        "Name[ro]": "Extensie Libarchive",
        "Name[ru]": "Модуль Libarchive",
        "Name[sk]": "Plugin Libarchive",
        "Name[sl]": "Vstavek Libarchive",
        "Name[sr@ijekavian]": "Прикључак за Либархив",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive",
        "Name[sr@latin]": "Priključak za libarchive",
        "Name[sr]": "Прикључак за Либархив",
        "Name[sv]": "Libarchive-insticksprogram",
        "Name[tr]": "Libarchive eklentisi",
        "Name[uk]": "Додаток libarchive",
        "Name[x-test]": "xxLibarchive pluginxx",
        "Name[zh_CN]": "Libarchive 插件",
        "Name[zh_TW]": "Libarchive 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 100,
    "application/x-bzip-compressed-tar": {
        "CompressionLevelDefault": 9,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lrzip-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lz4-compressed-tar": {
        "CompressionLevelDefault": 1,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-lzip-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-lzma-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-tzo": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1
    },
    "application/x-xz-compressed-tar": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0
    },
    "application/x-zstd-compressed-tar": {
        "CompressionLevelDefault": 3,
        "CompressionLevelMax": 22,
        "CompressionLevelMin": 1
    }
}
